==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-drools/kie-internal/src/main/java/org/kie/internal/builder/conf/LanguageLevelOption.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.kie.internal.builder.conf;

import org.kie.api.conf.OptionKey;

/**
 * A class for the language level configuration.
 */
public enum LanguageLevelOption implements SingleValueRuleBuilderOption {

    DRL5(false), DRL6(false), DRL6_STRICT(true);

    private final boolean useJavaAnnotations;

    /**
     * The property name for the language level
     */
    public static final String PROPERTY_NAME = "drools.lang.level";

    public static OptionKey<LanguageLevelOption> KEY = new OptionKey<>(TYPE, PROPERTY_NAME);

    LanguageLevelOption(boolean useJavaAnnotations) {
        this.useJavaAnnotations = useJavaAnnotations;
    }

    public boolean useJavaAnnotations() {
        return useJavaAnnotations;
    }

    /**
     * {@inheritDoc}
     */
    public String getPropertyName() {
        return PROPERTY_NAME;
    }

}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-drools/kie-internal/src/main/java/org/kie/internal/builder/conf/LanguageLevelOption.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.kie.internal.builder.conf;

import org.kie.api.conf.OptionKey;

/**
 * A class for the language level configuration.
 */
public enum LanguageLevelOption implements SingleValueRuleBuilderOption {

    DRL5(false), DRL6(false), DRL6_STRICT(true), DRL10(false);

    private final boolean useJavaAnnotations;

    /**
     * The property name for the language level
     */
    public static final String PROPERTY_NAME = "drools.lang.level";

    public static OptionKey<LanguageLevelOption> KEY = new OptionKey<>(TYPE, PROPERTY_NAME);

    LanguageLevelOption(boolean useJavaAnnotations) {
        this.useJavaAnnotations = useJavaAnnotations;
    }

    public boolean useJavaAnnotations() {
        return useJavaAnnotations;
    }

    /**
     * {@inheritDoc}
     */
    public String getPropertyName() {
        return PROPERTY_NAME;
    }

}
